You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@geode.apache.org by kl...@apache.org on 2016/02/24 23:09:44 UTC

incubator-geode git commit: GEODE-998: Fix javadoc warning in LogConfig

Repository: incubator-geode
Updated Branches:
  refs/heads/develop d8522c23a -> 37993890c


GEODE-998: Fix javadoc warning in LogConfig


Project: http://git-wip-us.apache.org/repos/asf/incubator-geode/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-geode/commit/37993890
Tree: http://git-wip-us.apache.org/repos/asf/incubator-geode/tree/37993890
Diff: http://git-wip-us.apache.org/repos/asf/incubator-geode/diff/37993890

Branch: refs/heads/develop
Commit: 37993890cb9a4f6ddb094191a438adb0356e9b23
Parents: d8522c2
Author: Kirk Lund <kl...@pivotal.io>
Authored: Wed Feb 24 14:08:31 2016 -0800
Committer: Kirk Lund <kl...@pivotal.io>
Committed: Wed Feb 24 14:09:19 2016 -0800

----------------------------------------------------------------------
 .../java/com/gemstone/gemfire/internal/logging/LogConfig.java    | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/37993890/geode-core/src/main/java/com/gemstone/gemfire/internal/logging/LogConfig.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/com/gemstone/gemfire/internal/logging/LogConfig.java b/geode-core/src/main/java/com/gemstone/gemfire/internal/logging/LogConfig.java
old mode 100644
new mode 100755
index 3e4fbc6..edd66c2
--- a/geode-core/src/main/java/com/gemstone/gemfire/internal/logging/LogConfig.java
+++ b/geode-core/src/main/java/com/gemstone/gemfire/internal/logging/LogConfig.java
@@ -16,6 +16,8 @@
  */
 package com.gemstone.gemfire.internal.logging;
 
+import com.gemstone.gemfire.distributed.internal.DistributionConfig;
+
 import java.io.File;
 
 public interface LogConfig {
@@ -54,7 +56,7 @@ public interface LogConfig {
    * A name is optional and by default empty.
    * If set it must be unique in the ds.
    * When set its used by tools to help identify the member.
    * <p> The default value is: {@link #DEFAULT_NAME}.
    * @return the system's name.
    */
   public String getName();
@@ -54,7 +56,7 @@ public interface LogConfig {
    * If set it must be unique in the ds.
    * When set its used by tools to help identify the member.
-   * <p> The default value is: {@link #DEFAULT_NAME}.
+   * <p> The default value is: {@link DistributionConfig#DEFAULT_NAME}.
    * @return the system's name.
    */